{% extends 'crudlfap/form.html' %}

{% block breadcrumb %}
{#
<nav class="breadcrumb">
  {% include 'crudlfap/_breadcrumb_object.html' %}
</nav>
#}
{% endblock %}

{% block content %}
  {{ _('Are you sure?') }}
  <br />
{% endblock %}
